%% Compiled by Frank E. Walter (2007); in part based on materials by
%% Rita Kis, Frank Schweitzer, and others.

%% --- Identification part ---
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ETHpaper}[2007/04/19 v1.0.0 ETH Paper]

%% --- Package loading ---
\RequirePackage{ifthen}

\newboolean{@logo}
\setboolean{@logo}{false}
\DeclareOption{logo}{\setboolean{@logo}{true}} 
\DeclareOption{nologo}{\setboolean{@logo}{false}}

\newboolean{@url}
\setboolean{@url}{true}
\DeclareOption{url}{\setboolean{@url}{true}} 
\DeclareOption{nourl}{\setboolean{@url}{false}}

%% --- Declaration of options ---
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}

%% --- Execution of options ---
\ProcessOptions
\LoadClass[a4paper]{article}

%% --- Special commands for package and class files ---
\usepackage{lastpage}
\usepackage{hyperref}

\usepackage[T1]{fontenc}
\usepackage[NewCommands]{ragged2e}

%% --- Special class file commands ---

%% --- Defining the (sub-)class ---
\oddsidemargin 0pt
\evensidemargin 0pt
\topmargin 0pt
\footskip 40pt
\headheight 62pt
\headsep 35pt
\textheight 20cm
\textwidth 16cm
\columnsep 10pt
\columnseprule 0pt
\clubpenalty=5000
\widowpenalty=5000

\sloppy
\frenchspacing

%% --- Spaces ---

\setlength{\parindent}{0pt}
\setlength{\parskip}{5pt plus 2pt minus 1pt}
\renewcommand{\baselinestretch}{1.095}
\renewcommand{\footnoterule}{\vspace{0.5cm}\rule{2.5in}{0.4pt}\vspace{0.3cm}}

%% --- Handling of floats ---

\renewcommand{\textfraction}{0.05}
\renewcommand{\topfraction}{0.95}
\renewcommand{\bottomfraction}{0.95}
\renewcommand{\floatpagefraction}{0.95}

%% --- Special variables ---

\newcommand{\titlecontent}{}
\renewcommand{\title}[1]{
  \renewcommand{\titlecontent}{#1}
}

\newcommand{\titlealternativecontent}{\titlecontent}
\newcommand{\titlealternative}[1]{
  \renewcommand{\titlealternativecontent}{#1}
}

\newcommand{\authorcontent}{}
\renewcommand{\author}[1]{
  \renewcommand{\authorcontent}{#1}
}

\newcommand{\authoralternativecontent}{\authorcontent}
\newcommand{\authoralternative}[1]{
  \renewcommand{\authoralternativecontent}{#1}
}

\newcommand{\addresscontent}{}
\newcommand{\address}[1]{
  \renewcommand{\addresscontent}{#1}
}

\newcommand{\referencecontent}{}
\newcommand{\reference}[1]{
  \renewcommand{\referencecontent}{#1}
}

\newcommand{\wwwcontent}{}
\newcommand{\www}[1]{
  \renewcommand{\wwwcontent}{#1}
}

%% --- Maketitle ---

\renewcommand{\maketitle}{
\makeframing
\begin{center}
   \textbf{\Large \titlecontent}\\[5mm]
   \textbf{\large \authorcontent \\}
%   \begin{quote}  quote needed only for more than one address
%     \begin{itemize} itemize needed only for more than one address
%     \item[$^{1}$] 
       \addresscontent
%     \item[$^{2}$] ...
%     \end{itemize}
%   \end{quote}
\end{center}
}

%% --- Makeframing ---

\RequirePackage{fancyhdr}

\pagestyle{fancy}

\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0.4pt}

\ifthenelse{\boolean{@logo}}{\RequirePackage{ETHlogo}}{}

\newcommand{\makeframing}{
\ifthenelse{\boolean{@logo}}{\logohead}{\nologohead}
}

\newcommand{\logohead}{
    \fancyhead[L]{}
    \fancyhead[C]{  \hrulefill \\[1ex]
        \begin{minipage}[c]{0.3\linewidth}
    \ETHlogo[42mm]
       \\{\footnotesize \ifthenelse{\boolean{@url}}{\wwwcontent}{}}    
        \end{minipage}\hfill
        \begin{minipage}[c]{0.7\linewidth}
          {\footnotesize{\raggedright
              \authoralternativecontent : \\
              \titlealternativecontent \\
              \referencecontent }}
        \end{minipage}\\[-1ex]
    \hrulefill}
    \fancyhead[R]{}
}

\newcommand{\nologohead}{
    \fancyhead[L]{}
    \fancyhead[C]{  \hrulefill \\[1ex]
        \begin{minipage}[c]{1.0\linewidth}
            %\begin{center}
            \LaTeXcentering
              {\footnotesize{
                  \authoralternativecontent : \\
                  \titlealternativecontent \\
                  \referencecontent }}
            %\end{center}
        \end{minipage}\\[-1ex]
        \hrulefill}
    \fancyhead[R]{}
}

\fancyfoot[L]{}
\fancyfoot[C]{\thepage /\pageref{LastPage}}
\fancyfoot[R]{}

\thispagestyle{fancy}





